#!/bin/bash

if [ "$1" == "i" ]; then
  if [ "$2" == "64" ]; then
    # set environment variables used by OCCT
    export CSF_FPE=0

    export TCL_DIR="${THIRDPARTY_DIR}/lib64"
    export TK_DIR=""
    export FREETYPE_DIR=""
    export FREEIMAGE_DIR=""
    export TBB_DIR=""
    export VTK_DIR="${THIRDPARTY_DIR}/lib64"
    export FFMPEG_DIR=""
    export JEMALLOC_DIR=""

    if [ "x" != "x" ]; then
      export QTDIR=""
    fi

    export TCL_VERSION_WITH_DOT=""
    export TK_VERSION_WITH_DOT=""

    export CSF_OCCTBinPath="${CASROOT}/lib64/opencascade/bin"
    export CSF_OCCTLibPath="${CASROOT}/lib64/opencascade"
    export CSF_OCCTIncludePath="${CASROOT}/include/opencascade"
    export CSF_OCCTResourcePath="${CASROOT}/share/opencascade/resources"
    export CSF_OCCTDataPath="${CASROOT}/share/opencascade/data"
    export CSF_OCCTSamplesPath="${CASROOT}/share/opencascade/samples"
    export CSF_OCCTTestsPath="${CASROOT}/share/opencascade/tests"
    export CSF_OCCTDocPath="${CASROOT}/share/doc/opencascade-7.8.1"
  fi
fi

